package com.gic.finance.dto;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.Date;

/**
 * 转账审批
 * @ClassName: TransferAccountsApprovalDTO 
 * @Description:  
 * @author guojuxing 
 * @date 2019/8/9 11:09 AM 
 */
public class TransferAccountsApprovalDTO implements Serializable{
    private static final long serialVersionUID = -7424594607676731039L;

    /**
     * 发起审批参数验证分组
     */
    public interface InitiateApprovalValid {
    }

    /**
     * 审批参数验证分组
     */
    public interface ApprovalValid {
    }
    /**
     *
     */
    @NotNull(message = "转账审批主键不能为空", groups = {ApprovalValid.class})
    private Integer transferApprovalId;

    /**
     * 关联订单流水号
     */
    @NotBlank(message = "关联订单流水号不能为空", groups = {InitiateApprovalValid.class})
    private String orderNumber;

    /**
     * 关联订单平台方（商户类型）1:GIC 2: 好办
     */
    @NotNull(message = "关联订单平台方不能为空", groups = {InitiateApprovalValid.class})
    private Integer platformType;

    /**
     * 发起方1：商户 2:运维后台
     */
    @NotNull(message = "发起方类型不能为空", groups = {InitiateApprovalValid.class})
    private Integer initiatorType;

    /**
     * 发起方姓名
     */
    @NotBlank(message = "发起方姓名不能为空", groups = {InitiateApprovalValid.class})
    private String initiatorName;

    /**
     *
     */
    @NotNull(message = "商户ID不能为空", groups = {InitiateApprovalValid.class})
    private Integer enterpriseId;

    /**
     * 计划金额
     */
    @NotNull(message = "计划金额不能为空", groups = {InitiateApprovalValid.class})
    private Double plannedAmount;

    /**
     * 坏账金额
     */
    private Double badAmount;

    /**
     * 到账金额
     */
    private Double accountAmount;

    /**
     * 验证码
     */
    @NotBlank(message = "验证码不能为空", groups = {InitiateApprovalValid.class})
    private String verifyCode;

    /**
     * 审批流水号
     */
    private String approvalNumber;

    /**
     * 审批状态 1:待审批 2:已取消 3:已驳回 4:审批通过
     */
    private Integer approvalStatus;

    /**
     * 审批人
     */
    private String approvalId;

    /**
     * 审批人姓名
     */
    private String approvalName;

    /**
     * 审批时间
     */
    private Date approvalTime;

    /**
     *
     */
    private Date createTime;

    /**
     *
     */
    private Date updateTime;

    /**
     * 审批人手机号码
     */
    private String approvalPhone;

    /**
     * 审批人手机号国际区号
     */
    private String approvalPhoneAreaCode;

    /**
     * 商户名称
     */
    @NotBlank(message = "商户名称不能为空", groups = {InitiateApprovalValid.class})
    private String enterpriseName;

    /**
     * 公司名称
     */
    @NotBlank(message = "公司名称不能为空", groups = {InitiateApprovalValid.class})
    private String companyName;

    /**
     * 公司logo
     */
    @NotBlank(message = "公司logo不能为空", groups = {InitiateApprovalValid.class})
    private String logo;
    /**
     * 1:套餐包 2:拓展包 3:服务 4:短信套餐包 5:充值
     */
    private Integer orderType;

    public Integer getTransferApprovalId() {
        return transferApprovalId;
    }

    public void setTransferApprovalId(Integer transferApprovalId) {
        this.transferApprovalId = transferApprovalId;
    }

    public String getOrderNumber() {
        return orderNumber;
    }

    public void setOrderNumber(String orderNumber) {
        this.orderNumber = orderNumber;
    }

    public Integer getPlatformType() {
        return platformType;
    }

    public void setPlatformType(Integer platformType) {
        this.platformType = platformType;
    }

    public Integer getInitiatorType() {
        return initiatorType;
    }

    public void setInitiatorType(Integer initiatorType) {
        this.initiatorType = initiatorType;
    }

    public String getInitiatorName() {
        return initiatorName;
    }

    public void setInitiatorName(String initiatorName) {
        this.initiatorName = initiatorName;
    }

    public Integer getEnterpriseId() {
        return enterpriseId;
    }

    public void setEnterpriseId(Integer enterpriseId) {
        this.enterpriseId = enterpriseId;
    }

    public Double getPlannedAmount() {
        return plannedAmount;
    }

    public void setPlannedAmount(Double plannedAmount) {
        this.plannedAmount = plannedAmount;
    }

    public Double getBadAmount() {
        return badAmount;
    }

    public void setBadAmount(Double badAmount) {
        this.badAmount = badAmount;
    }

    public Double getAccountAmount() {
        return accountAmount;
    }

    public void setAccountAmount(Double accountAmount) {
        this.accountAmount = accountAmount;
    }

    public String getVerifyCode() {
        return verifyCode;
    }

    public void setVerifyCode(String verifyCode) {
        this.verifyCode = verifyCode;
    }

    public String getApprovalNumber() {
        return approvalNumber;
    }

    public void setApprovalNumber(String approvalNumber) {
        this.approvalNumber = approvalNumber;
    }

    public Integer getApprovalStatus() {
        return approvalStatus;
    }

    public void setApprovalStatus(Integer approvalStatus) {
        this.approvalStatus = approvalStatus;
    }

    public String getApprovalId() {
        return approvalId;
    }

    public void setApprovalId(String approvalId) {
        this.approvalId = approvalId;
    }

    public String getApprovalName() {
        return approvalName;
    }

    public void setApprovalName(String approvalName) {
        this.approvalName = approvalName;
    }

    public Date getApprovalTime() {
        return approvalTime;
    }

    public void setApprovalTime(Date approvalTime) {
        this.approvalTime = approvalTime;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getApprovalPhone() {
        return approvalPhone;
    }

    public void setApprovalPhone(String approvalPhone) {
        this.approvalPhone = approvalPhone;
    }

    public String getApprovalPhoneAreaCode() {
        return approvalPhoneAreaCode;
    }

    public void setApprovalPhoneAreaCode(String approvalPhoneAreaCode) {
        this.approvalPhoneAreaCode = approvalPhoneAreaCode;
    }

    public String getEnterpriseName() {
        return enterpriseName;
    }

    public void setEnterpriseName(String enterpriseName) {
        this.enterpriseName = enterpriseName;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public Integer getOrderType() {
        return orderType;
    }

    public void setOrderType(Integer orderType) {
        this.orderType = orderType;
    }
}
