package com.gic.finance.web.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.dto.BillingOrderDTO;
import com.gic.enterprise.dto.BillingRechargeRecordDTO;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.enterprise.service.BillingOrderApiService;
import com.gic.enterprise.service.BillingRechargeRecordApiService;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.finance.constant.OrderTypeEnum;
import com.gic.finance.dto.TransferAccountsApprovalDTO;
import com.gic.finance.qo.TransferListQueryQO;
import com.gic.finance.service.TransferAccountsApprovalApiService;
import com.gic.finance.web.vo.TransferApprovalListVO;
import com.gic.finance.web.vo.TransferApprovalRechargeVO;
import com.gic.finance.web.vo.TransferApprovalSmsVO;

/**
 * 转账审批
 * @ClassName: TransferAccountsApprovalController 
 * @Description:  
 * @author guojuxing 
 * @date 2019/8/9 5:05 PM 
 */
@RestController
@RequestMapping("/transfer-accounts-approval")
public class TransferAccountsApprovalController {
    private static final Logger LOGGER = LoggerFactory.getLogger(TransferAccountsApprovalController.class);

    @Autowired
    private TransferAccountsApprovalApiService transferAccountsApprovalApiService;
    @Autowired
    private BillingOrderApiService billingOrderApiService;
    @Autowired
    private BillingRechargeRecordApiService billingRechargeRecordApiService;

    @RequestMapping("/get-approval")
    public RestResponse getById(Integer id) {
        ServiceResponse<TransferAccountsApprovalDTO> transferResult = transferAccountsApprovalApiService.getById(id);
        if (transferResult.isSuccess()) {
            TransferAccountsApprovalDTO transfer = transferResult.getResult();
            //短信套餐包
            if (transfer.getOrderType().intValue() == OrderTypeEnum.SHORT_MESSAGE_PACKAGE.getCode()) {
                ServiceResponse<BillingOrderDTO> orderDetail = billingOrderApiService
                        .getOrderBySerialNumber(transfer.getOrderNumber());

                TransferApprovalSmsVO vo = EntityUtil.changeEntityNew(TransferApprovalSmsVO.class, transfer);
                if (orderDetail.isSuccess()) {
                    BillingOrderDTO order = orderDetail.getResult();
                    //订单详情
                    vo.setOrderItemJson(order.getItemJson());
                    vo.setPayInfoSerialNumber(order.getPayInfoSerialNumber());
                    vo.setCouponCardContent(order.getCouponCardContent());
                    vo.setCouponCardName(order.getCouponCardName());
                    return RestResponse.success(vo);
                } else {
                    return EnterpriseRestResponse.failure(orderDetail);
                }
            } else if (transfer.getOrderType().intValue() == OrderTypeEnum.RECHARGE.getCode()) {
                TransferApprovalRechargeVO vo = EntityUtil.changeEntityNew(TransferApprovalRechargeVO.class, transfer);

                ServiceResponse<BillingRechargeRecordDTO> rechargeResult = billingRechargeRecordApiService
                        .getRechargeRecordForApproval(transfer.getOrderNumber());
                if (rechargeResult.isSuccess()) {
                    BillingRechargeRecordDTO recharge = rechargeResult.getResult();
                    //支付流水号
                    vo.setPayInfoSerialNumber(recharge.getPayInfoSerialNumber());
                    return RestResponse.success(vo);
                } else {
                    return EnterpriseRestResponse.failure(rechargeResult);
                }
            } else {
                return RestResponse.failure(ErrorCode.SYSTEM_ERROR.getCode(), "目前没有该类型的数据");
            }
        } else {
            return EnterpriseRestResponse.failure(transferResult);
        }
    }

    @RequestMapping("/agree-approval")
    public RestResponse agreeApproval(Integer id, Double accountAmount) {
        return ResultControllerUtils.commonResult(transferAccountsApprovalApiService.agreeApproval(id, accountAmount));
    }

    @RequestMapping("/cancel-approval")
    public RestResponse cancelApproval(Integer id) {
        return ResultControllerUtils.commonResult(transferAccountsApprovalApiService.cancelApproval(id));
    }

    @RequestMapping("/list-approval")
    public RestResponse listTransferAccountsApproval(TransferListQueryQO params) {
        return ResultControllerUtils.commonPageResult(
                transferAccountsApprovalApiService.listTransferAccountsApproval(params), TransferApprovalListVO.class);
    }
}
